==> openshift-model-5.8.0-sources.jar: io/fabric8/openshift/api/model/AWSPlatformSpecFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AWSPlatformSpecFluent<A extends io.fabric8.openshift.api.model.AWSPlatformSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToServiceEndpoints(java.lang.Integer index,io.fabric8.openshift.api.model.AWSServiceEndpoint item);
  public A setToServiceEndpoints(java.lang.Integer index,io.fabric8.openshift.api.model.AWSServiceEndpoint item);
  public A addToServiceEndpoints(io.fabric8.openshift.api.model.AWSServiceEndpoint... items);
  public A addAllToServiceEndpoints(java.util.Collection<io.fabric8.openshift.api.model.AWSServiceEndpoint> items);
  public A removeFromServiceEndpoints(io.fabric8.openshift.api.model.AWSServiceEndpoint... items);
  public A removeAllFromServiceEndpoints(java.util.Collection<io.fabric8.openshift.api.model.AWSServiceEndpoint> items);
  public A removeMatchingFromServiceEndpoints(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildServiceEndpoints instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.AWSServiceEndpoint> getServiceEndpoints();
  public java.util.List<io.fabric8.openshift.api.model.AWSServiceEndpoint> buildServiceEndpoints();
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildServiceEndpoint(java.lang.Integer index);
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildFirstServiceEndpoint();
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildLastServiceEndpoint();
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildMatchingServiceEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate);
  public java.lang.Boolean hasMatchingServiceEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate);
  public A withServiceEndpoints(java.util.List<io.fabric8.openshift.api.model.AWSServiceEndpoint> serviceEndpoints);
  public A withServiceEndpoints(io.fabric8.openshift.api.model.AWSServiceEndpoint... serviceEndpoints);
  public java.lang.Boolean hasServiceEndpoints();
  public A addNewServiceEndpoint(java.lang.String name,java.lang.String url);
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> addNewServiceEndpoint();
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> addNewServiceEndpointLike(io.fabric8.openshift.api.model.AWSServiceEndpoint item);
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> setNewServiceEndpointLike(java.lang.Integer index,io.fabric8.openshift.api.model.AWSServiceEndpoint item);
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editServiceEndpoint(java.lang.Integer index);
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editFirstServiceEndpoint();
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editLastServiceEndpoint();
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editMatchingServiceEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate);
  public interface ServiceEndpointsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.AWSServiceEndpointFluent<io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<N>>{
    public N and();
    public N endServiceEndpoint();
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/AWSPlatformSpecFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AWSPlatformSpecFluent<A extends io.fabric8.openshift.api.model.AWSPlatformSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToServiceEndpoints(java.lang.Integer index,io.fabric8.openshift.api.model.AWSServiceEndpoint item);
  public A setToServiceEndpoints(java.lang.Integer index,io.fabric8.openshift.api.model.AWSServiceEndpoint item);
  public A addToServiceEndpoints(io.fabric8.openshift.api.model.AWSServiceEndpoint... items);
  public A addAllToServiceEndpoints(java.util.Collection<io.fabric8.openshift.api.model.AWSServiceEndpoint> items);
  public A removeFromServiceEndpoints(io.fabric8.openshift.api.model.AWSServiceEndpoint... items);
  public A removeAllFromServiceEndpoints(java.util.Collection<io.fabric8.openshift.api.model.AWSServiceEndpoint> items);
  public A removeMatchingFromServiceEndpoints(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildServiceEndpoints instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.AWSServiceEndpoint> getServiceEndpoints();
  public java.util.List<io.fabric8.openshift.api.model.AWSServiceEndpoint> buildServiceEndpoints();
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildServiceEndpoint(java.lang.Integer index);
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildFirstServiceEndpoint();
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildLastServiceEndpoint();
  public io.fabric8.openshift.api.model.AWSServiceEndpoint buildMatchingServiceEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate);
  public java.lang.Boolean hasMatchingServiceEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate);
  public A withServiceEndpoints(java.util.List<io.fabric8.openshift.api.model.AWSServiceEndpoint> serviceEndpoints);
  public A withServiceEndpoints(io.fabric8.openshift.api.model.AWSServiceEndpoint... serviceEndpoints);
  public java.lang.Boolean hasServiceEndpoints();
  public A addNewServiceEndpoint(java.lang.String name,java.lang.String url);
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> addNewServiceEndpoint();
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> addNewServiceEndpointLike(io.fabric8.openshift.api.model.AWSServiceEndpoint item);
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> setNewServiceEndpointLike(java.lang.Integer index,io.fabric8.openshift.api.model.AWSServiceEndpoint item);
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editServiceEndpoint(java.lang.Integer index);
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editFirstServiceEndpoint();
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editLastServiceEndpoint();
  public io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<A> editMatchingServiceEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.AWSServiceEndpointBuilder> predicate);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ServiceEndpointsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.AWSServiceEndpointFluent<io.fabric8.openshift.api.model.AWSPlatformSpecFluent.ServiceEndpointsNested<N>>{
    public N and();
    public N endServiceEndpoint();
    
  }
  
}
